@@ -23,11 +23,16 @@ around 'parse_datetime' => sub {
 	;
 
 	## Set Pattern: from args, then from object
-	my $pattern = $env->{ override }->{ pattern }
-		// $self->has_pattern
-		? $self->pattern
-		: croak "No pattern supplied to constructor or the call to parse_datetime"
-	;
+	my $pattern
+	if ( defined $env->{override}{pattern} ) {
+		$pattern = $self->{override}{pattern}
+	}
+	elsif ( $self->has_pattern ) {
+		$pattern = $self->pattern
+	}
+	else {
+		croak "No pattern supplied to constructor or the call to parse_datetime"
+	}
 
 	$env->{ pattern } = $pattern;
 	
@@ -36,8 +41,6 @@ around 'parse_datetime' => sub {
 
 };
 
-no Moose::Role;
-
 1;
 
 __END__
